==> nextcloud-29.0.12.tgz: nextcloud/apps/federatedfilesharing/l10n/uk.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Неправильний Об'єднаний Хмарний Ідентіфікатор ",
    "Server to server sharing is not enabled on this server" : "На цьому сервері вимкнута можливість передавання даних між серверами",
    "Couldn't establish a federated share." : "Не вдалося встановити об’єднаний спільний доступ.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не вдалося встановити спільний доступ до об'єднаної хмари, можливо, пароль неправильний.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Запит на Federated Share надіслано, ви отримаєте запрошення. Перевірте сповіщення.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не вдалося встановити об’єднаний ресурс, схоже, сервер, з яким потрібно об’єднатися, застарий (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Заборонено надсилати об’єднані спільні групи з цього сервера.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Не вдалося надати %1$s у спільний доступ, оскільки цей ресурс вже надано у спільний доступ користувачеві %2$s",
    "Not allowed to create a federated share to the same account" : "Не дозволяється створювати об'єднані ресурси для одного облікового запису",
    "Federated shares require read permissions" : "Об’єднані спільні ресурси потребують дозволу на читання",
    "File is already shared with %s" : "Файл вже в загальному доступі з %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Помилка спільного доступу %1$s, не вдалося знайти %2$s, можливо, сервер наразі недоступний або використовує самопідписаний сертифікат.",
    "Could not find share" : "Не вдалося знайти спільний доступ",
    "Federated sharing" : "Об'єднаний спільний доступ",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Ви отримали {share} як віддалений спільний доступ від {user} (від імені {behalf})",
    "You received {share} as a remote share from {user}" : "Ви отримали {share} як віддалений спільний доступ від {user}",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "Federated Cloud Sharing" : "Спільні хмарні ресурси",
    "Sharing" : "Спільний доступ",
    "Federated file sharing" : "Інтегрований обмін файлами",
    "Provide federated file sharing across servers" : "Забезпечте об’єднаний обмін файлами між серверами",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Налаштуйте, як користувчі можуть надавати у спільний доступ ресурси користувачам інших серверів хмар. Це включає в себе надання у спільний доступ ресурсів користувачів як цього серверу, так і об'єднаних хмар.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Дозволити користувачам цієї хмари надавати ресурси у спільний доступ користувачам інших серверів хмар (цей параметр дозволить доступ через протокол WebDAV до публічних спільних ресурсів)",
    "Allow people on this server to receive shares from other servers" : "Дозволити користувачам цієї хмари отримувати доступ до спільних ресурсів користувачів з інших серверів хмар",
    "Allow people on this server to send shares to groups on other servers" : "Дозволити користувачам цієї хмари надавати у спільний доступ ресурси групам користувачів інших хмарних серверів",
    "Allow people on this server to receive group shares from other servers" : "Дозволити користувачам цієї хмари отримувати доступ до спільних ресурсів груп користувачів інших хмарних серверів",
    "Search global and public address book for people" : "Пошук по глобальній та публічній адресній книзі користувачів",
    "Allow people to publish their data to a global and public address book" : "Дозволити користувачам розміщувати власні дані у глобальній публічній адресній книзі",
    "Unable to update federated files sharing config" : "Неможливо оновити конфігурацію спільного доступу до об’єднаних файлів",
    "Federated Cloud" : "Об'єднана хмара",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Ви можете поділитися з будь-ким, хто використовує сервер Nextcloud або інші сервери та служби, сумісні з Open Cloud Mesh (OCM). Просто введіть їхній Federated Cloud ID у діалоговому вікні спільного доступу. Це виглядає як person@cloud.example.com",
    "Share it so your friends can share files with you:" : "Поділіться ним, щоб ваші друзі могли ділитися з вами файлами:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (раніше відома як Twitter)",
    "Add to your website" : "Додати на ваш вебсайт",
    "Share with me via Nextcloud" : "Поділися зі мною через Nextcloud",
    "HTML Code:" : "Код HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Поділіться зі мною через мій #Nextcloud Federated Cloud ID, див. {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Поділіться зі мною через мій #Nextcloud Federated Cloud ID",
    "Cloud ID copied to the clipboard" : "Cloud ID скопійовано в буфер обміну",
    "Copy to clipboard" : "Копіювати до буферу обміну",
    "Copied!" : "Скопійовано!",
    "Cancel" : "Скасувати",
    "Add remote share" : "Додати віддалений каталог",
    "Remote share" : "Віддалений каталог",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Додати віддалений каталог {name} з {owner}@{remote}?",
    "Remote share password" : "Пароль для віддаленого каталогу",
    "Your Federated Cloud ID:" : "Ваш ідентифікатор Federated Cloud:",
    "Twitter" : "Twitter",
    "Diaspora" : "Діаспора",
    "Clipboard is not available" : "Буфер обміну недоступний"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-30.0.13.tgz: nextcloud/apps/federatedfilesharing/l10n/uk.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Неправильний Об'єднаний Хмарний Ідентіфікатор ",
    "Server to server sharing is not enabled on this server" : "На цьому сервері вимкнута можливість передавання даних між серверами",
    "Couldn't establish a federated share." : "Не вдалося встановити об’єднаний спільний доступ.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не вдалося встановити спільний доступ до об'єднаної хмари, можливо, пароль неправильний.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Запит на Federated Share надіслано, ви отримаєте запрошення. Перевірте сповіщення.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не вдалося встановити об’єднаний ресурс, схоже, сервер, з яким потрібно об’єднатися, застарий (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Заборонено надсилати об’єднані спільні групи з цього сервера.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Не вдалося надати %1$s у спільний доступ, оскільки цей ресурс вже надано у спільний доступ користувачеві %2$s",
    "Not allowed to create a federated share to the same account" : "Не дозволяється створювати міжхмарні спільні ресурси для одного й того саме облікового запису",
    "Federated shares require read permissions" : "Об’єднані спільні ресурси потребують дозволу на читання",
    "File is already shared with %s" : "Файл вже в загальному доступі з %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Помилка спільного доступу %1$s, не вдалося знайти %2$s, можливо, сервер наразі недоступний або використовує самопідписаний сертифікат.",
    "Could not find share" : "Не вдалося знайти спільний доступ",
    "Federated sharing" : "Об'єднаний спільний доступ",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Ви отримали {share} як віддалений спільний доступ від {user} (від імені {behalf})",
    "You received {share} as a remote share from {user}" : "Ви отримали {share} як віддалений спільний доступ від {user}",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "Federated Cloud Sharing" : "Спільні хмарні ресурси",
    "Sharing" : "Спільний доступ",
    "Federated file sharing" : "Інтегрований обмін файлами",
    "Provide federated file sharing across servers" : "Забезпечте об’єднаний обмін файлами між серверами",
    "Unable to update federated files sharing config" : "Неможливо оновити конфігурацію спільного доступу до об’єднаних файлів",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Налаштуйте, як користувчі можуть надавати у спільний доступ ресурси користувачам інших серверів хмар. Це включає в себе надання у спільний доступ ресурсів користувачів як цього серверу, так і об'єднаних хмар.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Дозволити користувачам цієї хмари надавати ресурси у спільний доступ користувачам інших серверів хмар (цей параметр дозволить доступ через протокол WebDAV до публічних спільних ресурсів)",
    "Allow people on this server to receive shares from other servers" : "Дозволити користувачам цієї хмари отримувати доступ до спільних ресурсів користувачів з інших серверів хмар",
    "Allow people on this server to send shares to groups on other servers" : "Дозволити користувачам цієї хмари надавати у спільний доступ ресурси групам користувачів інших хмарних серверів",
    "Allow people on this server to receive group shares from other servers" : "Дозволити користувачам цієї хмари отримувати доступ до спільних ресурсів груп користувачів інших хмарних серверів",
    "Search global and public address book for people" : "Шукати користувачів у глобальній та публічній адресних книгах",
    "Allow people to publish their data to a global and public address book" : "Дозволити користувачам розміщувати власні дані у глобальній публічній адресній книзі",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Поділіться зі мною через мій #Nextcloud Federated Cloud ID, див. {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Поділіться зі мною через мій #Nextcloud Federated Cloud ID",
    "Share with me via Nextcloud" : "Поділися зі мною через Nextcloud",
    "Cloud ID copied to the clipboard" : "Cloud ID скопійовано в буфер обміну",
    "Copy to clipboard" : "Копіювати до буферу обміну",
    "Copied!" : "Скопійовано!",
    "Federated Cloud" : "Об'єднана хмара",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Ви можете поділитися з будь-ким, хто використовує сервер Nextcloud або інші сервери та служби, сумісні з Open Cloud Mesh (OCM). Просто введіть їхній Federated Cloud ID у діалоговому вікні спільного доступу. Це виглядає як person@cloud.example.com",
    "Share it so your friends can share files with you:" : "Поділіться ним, щоб ваші друзі могли ділитися з вами файлами:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (раніше відома як Twitter)",
    "Add to your website" : "Додати на ваш вебсайт",
    "HTML Code:" : "Код HTML:",
    "Cancel" : "Скасувати",
    "Add remote share" : "Додати віддалений каталог",
    "Remote share" : "Віддалений каталог",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Додати віддалений каталог {name} з {owner}@{remote}?",
    "Remote share password" : "Пароль для віддаленого каталогу"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
